Crate gannot

Crate gannot 

Gannot

Gannot is a small library with limited functionality focused on genome annotation. It is a result of factoring out code that I have found useful in various Rust projects.

It is unlikely to be more generally useful at this stage, but it provides a base for me to add further shared code—and to learn the Cargo ecosystem. If I have a chance to extend it, there are likely to be many breaking changes, so it is not recommended to use this package.

Currently, it provides convenience functions for specifying genomic coordinates and for parsing GFF3 and BED files.

License

Licensed under either

at your option.

Modules

format
Supports different genomic formats
genome
Functionality for referencing genome sequences